@@ -5,7 +5,7 @@ from my_app.context import ctx
 
 
 def create_widget_object(name: str):
-    request_id = 'request_id={0}'.format(ctx.request_id)
+    request_id = f'request_id={ctx.request_id}'
     logging.debug('%s going to create widget: %s', request_id, name)
 
     try:
